@@ -13,7 +13,7 @@
 #else
 #include <QGuiApplication>
 #endif
-#include "clipboard.h"
+#include "kontrast.h"
 #include <QCommandLineParser>
 #include <QDir>
 #include <QIcon>
@@ -23,7 +23,6 @@
 #include <QSqlError>
 #include <QStandardPaths>
 #include <QUrl>
-#include <kontrast.h>
 
 const QString DRIVER(QStringLiteral("QSQLITE"));
 
@@ -70,7 +69,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     qmlRegisterSingletonInstance("org.kde.kontrast.private", 1, 0, "Kontrast", &kontrast);
     qmlRegisterSingletonInstance("org.kde.kontrast.private", 1, 0, "ColorStore", new SavedColorModel(qApp));
-    qmlRegisterType<Clipboard>("org.kde.kontrast.private", 1, 0, "Clipboard");
     qmlRegisterSingletonType("org.kde.kontrast.private", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
         return engine->toScriptValue(KAboutData::applicationData());
     });
